@@ -5,11 +5,11 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     05-May-2017
-// Ver:      14-Oct-2021.
+// Ver:      30-May-2022.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2021    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2022    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -26,8 +26,8 @@
 //------------------------------------------------------------------------------
 
 
-double asum_float_simd(Py_ssize_t arraylen, float *data);
-double asum_float_simd_ovfl(Py_ssize_t arraylen, float *data, signed int *errflag);
+float asum_float_simd(Py_ssize_t arraylen, float *data);
+float asum_float_simd_ovfl(Py_ssize_t arraylen, float *data, signed int *errflag);
 double asum_double_simd(Py_ssize_t arraylen, double *data);
 double asum_double_simd_ovfl(Py_ssize_t arraylen, double *data, signed int *errflag);
 
