@@ -5,7 +5,7 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     08-Oct-2019
-// Ver:      06-Sep-2021.
+// Ver:      31-Oct-2021.
 //
 //------------------------------------------------------------------------------
 //
@@ -82,7 +82,7 @@ int8x8_t initvec_signed_char(signed char initval) {
 void neg_signed_char_1_simd(Py_ssize_t arraylen, signed char *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -96,18 +96,18 @@ void neg_signed_char_1_simd(Py_ssize_t arraylen, signed char *data) {
 	alignedlength = calcalignedlength(arraylen, CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += CHARSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1_s8( &data[index]);
+		datasliceleft = vld1_s8( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vneg_s8(datasliceleft);
 		// Store the result.
-		vst1_s8( &data[index],  datasliceleft);
+		vst1_s8( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		data[x] = -data[x];
 	}
 
 }
@@ -119,7 +119,7 @@ void neg_signed_char_1_simd(Py_ssize_t arraylen, signed char *data) {
 void neg_signed_char_2_simd(Py_ssize_t arraylen, signed char *data, signed char *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -133,18 +133,18 @@ void neg_signed_char_2_simd(Py_ssize_t arraylen, signed char *data, signed char
 	alignedlength = calcalignedlength(arraylen, CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += CHARSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1_s8( &data[index]);
+		datasliceleft = vld1_s8( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vneg_s8(datasliceleft);
 		// Store the result.
-		vst1_s8( &dataout[index],  datasliceleft);
+		vst1_s8( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		dataout[x] = -data[x];
 	}
 
 }
@@ -162,7 +162,7 @@ void neg_signed_char_2_simd(Py_ssize_t arraylen, signed char *data, signed char
 char neg_signed_char_1_simd_ovfl(Py_ssize_t arraylen, signed char *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -181,9 +181,9 @@ char neg_signed_char_1_simd_ovfl(Py_ssize_t arraylen, signed char *data) {
 	alignedlength = calcalignedlength(arraylen, CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += CHARSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1_s8( &data[index]);
+		datasliceleft = vld1_s8( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -198,13 +198,13 @@ char neg_signed_char_1_simd_ovfl(Py_ssize_t arraylen, signed char *data) {
 		datasliceleft = vneg_s8(datasliceleft);
 
 		// Store the result.
-		vst1_s8( &data[index],  datasliceleft);
+		vst1_s8( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_char(data[index]) ) {return ARR_ERR_OVFL;}
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_char(data[x]) ) {return ARR_ERR_OVFL;}
+		data[x] = -data[x];
 	}
 
 	return 0;
@@ -216,7 +216,7 @@ char neg_signed_char_1_simd_ovfl(Py_ssize_t arraylen, signed char *data) {
 char neg_signed_char_2_simd_ovfl(Py_ssize_t arraylen, signed char *data, signed char *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -235,9 +235,9 @@ char neg_signed_char_2_simd_ovfl(Py_ssize_t arraylen, signed char *data, signed
 	alignedlength = calcalignedlength(arraylen, CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += CHARSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1_s8( &data[index]);
+		datasliceleft = vld1_s8( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -252,13 +252,13 @@ char neg_signed_char_2_simd_ovfl(Py_ssize_t arraylen, signed char *data, signed
 		datasliceleft = vneg_s8(datasliceleft);
 
 		// Store the result.
-		vst1_s8( &dataout[index],  datasliceleft);
+		vst1_s8( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_char(data[index]) ) {return ARR_ERR_OVFL;}
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_char(data[x]) ) {return ARR_ERR_OVFL;}
+		dataout[x] = -data[x];
 	}
 
 	return 0;
@@ -301,7 +301,7 @@ int16x4_t initvec_signed_short(signed short initval) {
 void neg_signed_short_1_simd(Py_ssize_t arraylen, signed short *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -315,18 +315,18 @@ void neg_signed_short_1_simd(Py_ssize_t arraylen, signed short *data) {
 	alignedlength = calcalignedlength(arraylen, SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1_s16( &data[index]);
+		datasliceleft = vld1_s16( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vneg_s16(datasliceleft);
 		// Store the result.
-		vst1_s16( &data[index],  datasliceleft);
+		vst1_s16( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		data[x] = -data[x];
 	}
 
 }
@@ -338,7 +338,7 @@ void neg_signed_short_1_simd(Py_ssize_t arraylen, signed short *data) {
 void neg_signed_short_2_simd(Py_ssize_t arraylen, signed short *data, signed short *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -352,18 +352,18 @@ void neg_signed_short_2_simd(Py_ssize_t arraylen, signed short *data, signed sho
 	alignedlength = calcalignedlength(arraylen, SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1_s16( &data[index]);
+		datasliceleft = vld1_s16( &data[x]);
 		// The actual SIMD operation. 
 		datasliceleft = vneg_s16(datasliceleft);
 		// Store the result.
-		vst1_s16( &dataout[index],  datasliceleft);
+		vst1_s16( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		dataout[x] = -data[x];
 	}
 
 }
@@ -381,7 +381,7 @@ void neg_signed_short_2_simd(Py_ssize_t arraylen, signed short *data, signed sho
 char neg_signed_short_1_simd_ovfl(Py_ssize_t arraylen, signed short *data) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -400,9 +400,9 @@ char neg_signed_short_1_simd_ovfl(Py_ssize_t arraylen, signed short *data) {
 	alignedlength = calcalignedlength(arraylen, SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1_s16( &data[index]);
+		datasliceleft = vld1_s16( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -417,13 +417,13 @@ char neg_signed_short_1_simd_ovfl(Py_ssize_t arraylen, signed short *data) {
 		datasliceleft = vneg_s16(datasliceleft);
 
 		// Store the result.
-		vst1_s16( &data[index],  datasliceleft);
+		vst1_s16( &data[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_short(data[index]) ) {return ARR_ERR_OVFL;}
-		data[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_short(data[x]) ) {return ARR_ERR_OVFL;}
+		data[x] = -data[x];
 	}
 
 	return 0;
@@ -435,7 +435,7 @@ char neg_signed_short_1_simd_ovfl(Py_ssize_t arraylen, signed short *data) {
 char neg_signed_short_2_simd_ovfl(Py_ssize_t arraylen, signed short *data, signed short *dataout) {
 
 	// array index counter. 
-	Py_ssize_t index; 
+	Py_ssize_t x; 
 
 	// SIMD related variables.
 	Py_ssize_t alignedlength;
@@ -454,9 +454,9 @@ char neg_signed_short_2_simd_ovfl(Py_ssize_t arraylen, signed short *data, signe
 	alignedlength = calcalignedlength(arraylen, SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (x = 0; x < alignedlength; x += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
-		datasliceleft = vld1_s16( &data[index]);
+		datasliceleft = vld1_s16( &data[x]);
 
 		// Check for overflow. 
 		// Do an equal compare operation.
@@ -471,13 +471,13 @@ char neg_signed_short_2_simd_ovfl(Py_ssize_t arraylen, signed short *data, signe
 		datasliceleft = vneg_s16(datasliceleft);
 
 		// Store the result.
-		vst1_s16( &dataout[index],  datasliceleft);
+		vst1_s16( &dataout[x],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for (index = alignedlength; index < arraylen; index++) {
-		if ( minval_loop_willoverflow_signed_short(data[index]) ) {return ARR_ERR_OVFL;}
-		dataout[index] = -data[index];
+	for (x = alignedlength; x < arraylen; x++) {
+		if ( minval_loop_willoverflow_signed_short(data[x]) ) {return ARR_ERR_OVFL;}
+		dataout[x] = -data[x];
 	}
 
 	return 0;
@@ -485,3 +485,200 @@ char neg_signed_short_2_simd_ovfl(Py_ssize_t arraylen, signed short *data, signe
 }
 #endif
 
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data = The input data array.
+   dataout = The output data array.
+*/
+// param_arr_none
+#if defined(AF_HASSIMD_ARMv7_32BIT)
+void neg_float_1_simd(Py_ssize_t arraylen, float *data) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft;
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data[x]);
+		// The actual SIMD operation. 
+		datasliceleft = vneg_f32(datasliceleft);
+		// Store the result.
+		vst1_f32( &data[x], datasliceleft);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data[x] = -data[x];
+	}
+
+}
+
+
+
+// param_arr_arr
+void neg_float_2_simd(Py_ssize_t arraylen, float *data, float *dataout) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft;
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data[x]);
+		// The actual SIMD operation. 
+		datasliceleft = vneg_f32(datasliceleft);
+		// Store the result.
+		vst1_f32( &dataout[x], datasliceleft);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		dataout[x] = -data[x];
+	}
+
+}
+#endif
+
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data = The input data array.
+   dataout = The output data array.
+   Returns 1 if overflow occurred, else returns 0.
+*/
+// param_arr_none
+#if defined(AF_HASSIMD_ARMv7_32BIT)
+char neg_float_1_simd_ovfl(Py_ssize_t arraylen, float *data) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1_f32( checksliceinit);
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data[x]);
+		// The actual SIMD operation. 
+		datasliceleft = vneg_f32(datasliceleft);
+		// Store the result.
+		vst1_f32( &data[x], datasliceleft);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmul_f32(checkslice, datasliceleft);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data[x] = -data[x];
+		if (!isfinite(data[x])) {return 1;}
+	}
+
+	// Everything was OK.
+	return 0;
+
+}
+
+
+
+// param_arr_arr
+char neg_float_2_simd_ovfl(Py_ssize_t arraylen, float *data, float *dataout) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1_f32( checksliceinit);
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data[x]);
+		// The actual SIMD operation. 
+		datasliceleft = vneg_f32(datasliceleft);
+		// Store the result.
+		vst1_f32( &dataout[x], datasliceleft);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmul_f32(checkslice, datasliceleft);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		dataout[x] = -data[x];
+		if (!isfinite(dataout[x])) {return 1;}
+	}
+
+	// Everything was OK.
+	return 0;
+
+}
+#endif
+
